@@ -1,18 +1,18 @@
 package Term::Vspark;
 
-use 5.016002;
 use strict;
 use warnings;
 use POSIX;
+use Carp qw{ croak };
 
 our @ISA = qw();
 
-our $VERSION = '0.06';
+our $VERSION = '0.07'; # VERSION
 
 sub show_single_bar {
-    my $num     = shift;
-    my $max     = shift;
-    my $columns = shift;
+    my $num     = shift || 0;
+    my $max     = shift || 0;
+    my $columns = shift || 0;
 
     my @graph = qw{ ▏ ▎ ▍ ▌ ▋ ▊ ▉ █ };
     my $bar_num = ceil( $num * ( scalar(@graph) * $columns ) ) / $max;
@@ -38,13 +38,34 @@ sub show_graph {
     return $str;
 }
 
+# Helper method
+sub show_labeled_graph {
+    my %args     = @_;
+    my $max      = $args{'max'};
+    my $columns  = $args{'columns'};
+
+    if ( ref $args{'k_values'} ne q{HASH} ) {
+        croak 'k_values is not an HASH';
+    }
+    my %k_values = %{ $args{'k_values'} };
+
+    my $str = q{};
+    for my $i ( keys %k_values ) {
+        $str .= printf( "%10s %s\n", $i, show_single_bar($k_values{$i}, $max, $columns) );
+    }
+
+    return $str;
+}
+
 1;
+
 __END__
-# Below is stub documentation for your module. You'd better edit it!
+
+=pod
 
 =head1 NAME
 
-Term::Vspark - Perl extension for dispaying bars in the terminal
+Term::Vspark
 
 =head1 SYNOPSIS
 
@@ -80,13 +101,19 @@ Example:
 
 This will receive numbers from ARGV or STDIN and print out beutiful graph based on that data.
 
+=encoding utf-8
+
+=head1 NAME
+
+Term::Vspark - Perl extension for dispaying bars in the terminal
+
 =head1 SEE ALSO
 
 Original repo: https://github.com/LuRsT/vspark
 
 =head1 AUTHOR
 
-Gil Gonçalves <lt>lurst@gmail.com<gt>
+Gil Gonçalves <lurst@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -96,4 +123,15 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.16.2 or,
 at your option, any later version of Perl 5 you may have available.
 
+=head1 AUTHOR
+
+Gil Gonçalves <lurst@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Gil Gonçalves.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
